/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/* 
 * ezfc-font.h
 * Copyright (C) 2011-2012 Akira TAGOH
 * 
 * Authors:
 *   Akira TAGOH  <akira@tagoh.org>
 * 
 * This library is free software: you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation, either
 * version 3 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#if !defined (__EZFC_H__INSIDE) && !defined (__EZFC_COMPILATION)
#error "Only <libeasyfc/ezfc.h> can be included directly."
#endif

#ifndef __EZFC_FONT_H__
#define __EZFC_FONT_H__

#include <glib.h>
#include <fontconfig/fontconfig.h>

G_BEGIN_DECLS

/**
 * ezfc_font_t:
 *
 * All the fields in the <structname>ezfc_font_t</structname>
 * structure are private to the #ezfc_font_t implementation.
 */
typedef struct _ezfc_font_t	ezfc_font_t;


gboolean     ezfc_font_is_alias_font              (const gchar      *alias_name);
GList       *ezfc_font_get_list                   (const gchar      *language,
                                                   const gchar      *alias_name,
						   gboolean          localized_font_name);
GList       *ezfc_font_get_pattern_list           (const gchar      *language,
                                                   const gchar      *alias_name);
GList       *ezfc_font_get_alias_name_from_pattern(const FcPattern  *pattern);
ezfc_font_t *ezfc_font_new                        (void);
ezfc_font_t *ezfc_font_ref                        (ezfc_font_t      *font);
void         ezfc_font_unref                      (ezfc_font_t      *font);
FcPattern   *ezfc_font_get_pattern                (ezfc_font_t      *font);
gboolean     ezfc_font_set_pattern                (ezfc_font_t      *font,
                                                   const FcPattern  *pattern,
                                                   GError          **error);
const gchar *ezfc_font_get_family                 (ezfc_font_t      *font);
gboolean     ezfc_font_set_family                 (ezfc_font_t      *font,
                                                   const gchar      *font_name,
                                                   GError          **error);
void         ezfc_font_check_existence            (ezfc_font_t      *font,
                                                   gboolean          flag);

G_END_DECLS

#endif /* __EZFC_FONT_H__ */
